@@ -23,6 +23,6 @@ def plot_cases(df,date,y_label):
     plt.xticks(rotation=90)
     plt.show()
 
-def plot_confirmed_cases():
-    plot_cases(get_confirmed_cases(),date.today().strftime("%-m/%-d/%y"),'confirmed')
+def plot_confirmed_cases(date_in):
+    plot_cases(get_confirmed_cases(),date_in,'confirmed')
 
